/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.information;

import java.util.NoSuchElementException;

import de.ozgcloud.info.GrpcInformationByIdRequest;
import de.ozgcloud.info.GrpcInformationByIdResponse;
import de.ozgcloud.info.GrpcInformationRequest;
import de.ozgcloud.info.GrpcInformationResponse;
import de.ozgcloud.info.InformationServiceGrpc;
import io.grpc.Status;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;
import net.devh.boot.grpc.server.service.GrpcService;

@Log4j2
@GrpcService
@RequiredArgsConstructor
public class InformationGrpcService extends InformationServiceGrpc.InformationServiceImplBase {
	private final InformationService service;

	@Override
	public void getInformationById(final GrpcInformationByIdRequest request, StreamObserver<GrpcInformationByIdResponse> responseStreamObserver) {
		try {
			var information = service.getInformationById(request.getId());
			var grpcNachricht = InformationMapper.fromNachrichtEvent(information);

			responseStreamObserver.onNext(GrpcInformationByIdResponse.newBuilder().setNachricht(grpcNachricht).build());
			responseStreamObserver.onCompleted();
		} catch (NoSuchElementException e) {
			responseStreamObserver.onError(Status.INVALID_ARGUMENT.withDescription(e.getMessage()).asRuntimeException());
		}
	}

	@Override
	public void getInformation(GrpcInformationRequest request, StreamObserver<GrpcInformationResponse> responseStreamObserver) {
		var information = service.getInformationOfPostfach(request.getPostfachId());
		var nachrichten = information.stream().map(InformationMapper::fromNachrichtEvent).toList();
		responseStreamObserver.onNext(GrpcInformationResponse.newBuilder().addAllNachrichten(nachrichten).build());
		responseStreamObserver.onCompleted();
	}
}
