/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.nachricht;

import org.springframework.core.env.Environment;
import org.springframework.core.env.Profiles;
import org.springframework.stereotype.Component;

import de.ozgcloud.info.common.InvalidNachrichtenListUrlException;
import de.ozgcloud.info.common.NachrichtEvent;
import lombok.RequiredArgsConstructor;

@Component
@RequiredArgsConstructor
class NachrichtMapper {
	static final String LOCAL_PROFILE = "local";
	private static final String NACHRICHTEN_LIST_URL_REGEX = "^(dns:///)?[A-Za-z\\d-]+(\\.[A-Za-z\\d-]+){0,512}:\\d{1,5}$";
	static final String DNS_PREFIX = "dns:///";
	static final String NACHRICHTEN_LIST_URL_FORMAT = DNS_PREFIX + "%s";

	private final Environment environment;

	NachrichtEvent fromGrpcNachricht(GrpcNachricht grpcNachricht) {
		return NachrichtEvent.builder()
		  .postfachId(grpcNachricht.getPostfachId())
		  .nachrichtenListUrl(getNachrichtenListUrl(grpcNachricht))
		  .build();
	}

	String getNachrichtenListUrl(GrpcNachricht nachricht) {
		var nachrichtenListUrl = nachricht.getNachrichtenListUrl();
		if (environment.acceptsProfiles(Profiles.of(LOCAL_PROFILE))) {
			return nachrichtenListUrl;
		}

		if (!nachrichtenListUrl.matches(NACHRICHTEN_LIST_URL_REGEX)) {
			throw new InvalidNachrichtenListUrlException(nachrichtenListUrl);
		}

		return nachrichtenListUrl.startsWith(DNS_PREFIX) ? nachrichtenListUrl : NACHRICHTEN_LIST_URL_FORMAT.formatted(nachrichtenListUrl);
	}
}
