/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info;

import org.bson.types.ObjectId;

import de.ozgcloud.info.common.NachrichtEvent;
import de.ozgcloud.info.nachricht.GrpcFinishedNachrichtRequest;
import de.ozgcloud.info.nachricht.GrpcNachricht;
import de.ozgcloud.info.nachricht.GrpcNewNachrichtRequest;

public class NachrichtEventTestFactory {
	public static final ObjectId ID = new ObjectId();
	public static final String ID_STRING = new ObjectId().toHexString();
	public static final ObjectId EMPTY_ID = new ObjectId();
	public static final String POSTKORB_HANDLE = UserTestFactory.POSTKORB_HANDLE;
	public static final String EMPTY_POSTFACH_HANDLE = "73228744-a28a-4485-845b-d8cc02422760";
	public static final String URL = "localhost:6789";
	public static final String URL_WITH_DNS = "dns:///" + URL;

	public static NachrichtEvent createNachrichtEvent() {
		return createNachrichtEventBuilder().build();
	}

	public static NachrichtEvent.NachrichtEventBuilder createNachrichtEventBuilder() {
		return NachrichtEvent.builder()
		  .id(ID_STRING)
		  .postfachId(POSTKORB_HANDLE)
		  .nachrichtenListUrl(URL);
	}

	public static GrpcNewNachrichtRequest createNewNachrichtRequest() {
		return createNewNachrichtRequestBuilder().setNachricht(createGrpcNachricht()).build();
	}

	public static GrpcNewNachrichtRequest.Builder createNewNachrichtRequestBuilder() {
		return GrpcNewNachrichtRequest.newBuilder().setNachricht(createGrpcNachricht());
	}

	public static GrpcFinishedNachrichtRequest createFinishNachrichtRequest() {
		return GrpcFinishedNachrichtRequest.newBuilder().setNachricht(createGrpcNachricht()).build();
	}

	public static GrpcNachricht createGrpcNachricht() {
		return createGrpcNachrichtBuilder().build();
	}

	public static GrpcNachricht.Builder createGrpcNachrichtBuilder() {
		var nachrichtEvent = createNachrichtEvent();

		return GrpcNachricht.newBuilder()
		  .setPostfachId(nachrichtEvent.getPostfachId())
		  .setNachrichtenListUrl(nachrichtEvent.getNachrichtenListUrl());
	}
}
