/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.information;

import static de.ozgcloud.info.information.InfoManagerProperties.*;
import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.TestPropertySource;

import de.ozgcloud.common.test.ITCase;

@SpringBootTest(classes = { InfoManagerProperties.class })
@ITCase
class InfoManagerPropertiesITCase {
	@TestPropertySource(properties = {
	  InfoManagerProperties.PREFIX + ".postfachIdKeyName" + "=" + TestLoadingConfiguration.OTHER_POSTFACH_KEY,
	})
	@Nested
	class TestLoadingConfiguration {
		static final String OTHER_POSTFACH_KEY = "otherPostfachKey";

		@Autowired
		private InfoManagerProperties infoManagerProperties;

		@Test
		void shouldHaveProperties() {
			assertThat(infoManagerProperties).isNotNull();
		}

		@Test
		void testPostfachHandleKey() {
			assertThat(infoManagerProperties.getPostfachIdKeyName()).isEqualTo(OTHER_POSTFACH_KEY);
		}
	}

	@Nested
	class TestLoadingDefaultConfiguration {

		@Autowired
		private InfoManagerProperties infoManagerProperties;

		@Test
		void shouldHaveProperties() {
			assertThat(infoManagerProperties).isNotNull();
		}

		@Test
		void testPostfachHandleKey() {
			assertThat(infoManagerProperties.getPostfachIdKeyName()).isEqualTo(POSTKORBHANDLE);
		}
	}
}