/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.information;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.DirtiesContext;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;

import de.ozgcloud.info.GrpcInformationByIdRequest;
import de.ozgcloud.info.GrpcInformationRequest;
import de.ozgcloud.info.InformationServiceGrpc;
import de.ozgcloud.info.NachrichtEventTestFactory;
import io.grpc.StatusRuntimeException;
import net.devh.boot.grpc.client.inject.GrpcClient;

@SpringBootTest(properties = {
  "grpc.server.inProcessName=test",
  "grpc.server.port=-1",
  "grpc.client.inProcess.address=in-process:test"
})
@SpringJUnitConfig(classes = { InformationGrpcTestConfiguration.class })
@DirtiesContext
class InformationGrpcServiceNoEventsITCase {
	@GrpcClient("inProcess")
	private InformationServiceGrpc.InformationServiceBlockingStub service;

	@Nested
	class TestGetInformation {
		@Test
		void responseShouldHaveEmptyList() {
			var request = GrpcInformationRequest.newBuilder().setPostfachId(NachrichtEventTestFactory.EMPTY_POSTFACH_HANDLE).build();
			var response = service.getInformation(request);

			assertThat(response.getNachrichtenList()).isEmpty();
		}
	}

	@Nested
	class TestGetInformationById {
		@Test
		void shouldThrowException() {
			var request = GrpcInformationByIdRequest.newBuilder().setId(NachrichtEventTestFactory.EMPTY_ID.toHexString()).build();

			assertThatExceptionOfType(StatusRuntimeException.class).isThrownBy(() -> service.getInformationById(request));
		}
	}
}