/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.information;

import static org.assertj.core.api.Assertions.*;

import java.util.UUID;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.data.mongo.DataMongoTest;
import org.springframework.test.context.ContextConfiguration;
import org.testcontainers.junit.jupiter.Testcontainers;

import de.ozgcloud.info.MongoDBTestContainerConfig;
import de.ozgcloud.info.NachrichtEventTestFactory;

@DataMongoTest
@Testcontainers
@ContextConfiguration(classes = MongoDBTestContainerConfig.class)
class InformationRepositoryITCase {
	@Autowired
	InformationRepository informationManagerRepository;

	@Nested
	class TestNachrichtExistsEvent {
		@BeforeEach
		void init() {
			informationManagerRepository.deleteAll();
		}

		@Test
		void shouldGetNachrichtenByPostfachId() {
			informationManagerRepository.save(NachrichtEventTestFactory.createNachrichtEvent());

			var information = informationManagerRepository.findByPostfachId(NachrichtEventTestFactory.POSTKORB_HANDLE);

			assertThat(information).hasSize(1);
		}
	}

	@Nested
	class TestNoNachrichtExistsEvent {
		@BeforeEach
		void init() {
			informationManagerRepository.deleteAll();
		}

		@Test
		void shouldGetEmptyNachrichtenList() {
			var information = informationManagerRepository.findByPostfachId(UUID.randomUUID().toString());

			assertThat(information).isEmpty();
		}
	}
}
