/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.nachricht;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.test.autoconfigure.data.mongo.DataMongoTest;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.test.context.ContextConfiguration;
import org.testcontainers.junit.jupiter.Testcontainers;

import de.ozgcloud.info.MongoDBTestContainerConfig;
import de.ozgcloud.info.NachrichtEventTestFactory;
import de.ozgcloud.info.common.NachrichtEvent;

@DataMongoTest
@Testcontainers
@ContextConfiguration(classes = MongoDBTestContainerConfig.class)
public class NachrichtenRepositoryITCase {
	@Qualifier("nachrichtRepository")
	@Autowired
	private NachrichtRepository repository;

	@Nested
	class TestNewNachrichtEvent {
		private final NachrichtEvent nachrichtEvent = NachrichtEventTestFactory.createNachrichtEventBuilder().id(null).build();

		@BeforeEach
		void init() {
			repository.deleteAll();
		}

		@Test
		void shouldSaveNachricht() {
			repository.save(nachrichtEvent);

			var savedNachrichtEvent = repository.findByPostfachIdAndNachrichtenListUrl(NachrichtEventTestFactory.POSTKORB_HANDLE,
			  NachrichtEventTestFactory.URL);

			assertThat(savedNachrichtEvent).isPresent();
		}

		@Test
		void shouldThrowDuplicateKeyException() {
			repository.save(nachrichtEvent);

			var anotherNachrichtEvent = NachrichtEventTestFactory.createNachrichtEventBuilder().id(null).build();

			assertThatExceptionOfType(DuplicateKeyException.class).isThrownBy(() -> repository.save(anotherNachrichtEvent));
		}
	}

	@Nested
	class TestFinishNachrichtEvent {
		@BeforeEach
		void init() {
			repository.deleteAll();
			repository.save(NachrichtEventTestFactory.createNachrichtEvent());
		}

		@Test
		void shouldHaveNachricht() {
			var nachrichtEvent = repository.findByPostfachIdAndNachrichtenListUrl(NachrichtEventTestFactory.POSTKORB_HANDLE,
			  NachrichtEventTestFactory.URL);

			assertThat(nachrichtEvent).isPresent();
		}

		@Test
		void shouldDeleteNachricht() {
			repository.deleteByPostfachIdAndNachrichtenListUrl(NachrichtEventTestFactory.POSTKORB_HANDLE, NachrichtEventTestFactory.URL);

			var nachrichtEvent = repository.findByPostfachIdAndNachrichtenListUrl(NachrichtEventTestFactory.POSTKORB_HANDLE,
			  NachrichtEventTestFactory.URL);

			assertThat(nachrichtEvent).isEmpty();
		}
	}
}
